{
    "$graph": [
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "label": "output of infernal's cmsearch",
                    "id": "#main/table_hits"
                }
            ],
            "steps": [
                {
                    "run": "#extract-coords-from-cmsearch.cwl",
                    "in": [
                        {
                            "source": "#main/grep/5Ss",
                            "id": "#main/extract_5S_coords/infernal_matches"
                        }
                    ],
                    "out": [
                        "#main/extract_5S_coords/matched_seqs_with_coords"
                    ],
                    "id": "#main/extract_5S_coords"
                },
                {
                    "run": "#pull-5Ss.cwl",
                    "in": [
                        {
                            "source": "#main/table_hits",
                            "id": "#main/grep/hits"
                        }
                    ],
                    "out": [
                        "#main/grep/5Ss"
                    ],
                    "id": "#main/grep"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/extract_5S_coords/matched_seqs_with_coords",
                    "id": "#main/5S_coordinates"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "output from infernal cmsearch",
                    "type": "File",
                    "streamable": true,
                    "id": "#extract-coords-from-cmsearch.cwl/infernal_matches"
                }
            ],
            "baseCommand": "awk",
            "stdout": "matched_seqs_with_coords",
            "arguments": [
                "{print $1\"-\"$3\"/\"$8\"-\"$9\" \"$8\" \"$9\" \"$1}",
                "$(inputs.infernal_matches.path)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract-coords-from-cmsearch.cwl/matched_seqs_with_coords",
                    "outputBinding": {
                        "glob": "matched_seqs_with_coords"
                    }
                }
            ],
            "doc": "The awk script takes the output of Infernal's cmsearch so-called fmt=1 mode\nand makes it suitable for use by esl-sfetch, a sequence selector\n\nReading the user's guide for Infernal, Version 1.1.2; July 2016\nhttp://eddylab.org/infernal/Userguide.pdf#page=60 we see that\nthe relevant fields in the cmsearch output are:\n(column number: explanation)\n1: The name of the target sequence or profile\n3: The name of the query sequence or profile\n8: The start of the alignment of this hit with respect to the\n    sequence, numbered 1..L for a sequence of L residues.\n9: The end of the alignment of this hit with respect to the sequence,\n    numbered 1..L for a sequence of L residues\n\nLikewise the format esl-sfetch wants is: <newname> <from> <to> <source seqname>\n\nPutting it all together we see that the newname (which esl-sfetch with\noutput using) is a concatenation of the original name, the sequence\nnumber, and the coordinates.\n",
            "id": "#extract-coords-from-cmsearch.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#pull-5Ss.cwl/hits"
                }
            ],
            "stdin": "${inputs.hits.path}",
            "baseCommand": [
                "grep",
                "RF00002"
            ],
            "stdout": "5Ss",
            "outputs": [
                {
                    "type": "File",
                    "id": "#pull-5Ss.cwl/5Ss",
                    "outputBinding": {
                        "glob": "5Ss"
                    }
                }
            ],
            "id": "#pull-5Ss.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
